--[[

AFK Quit

This addon will call ForceQuit() right before you are supposed to be 
logged out for beeing Idle. This will return you back to your OS instead 
of going to the character selection screen and then beeing dropped back 
to the login screen.

The idea is to avoid running your graphics card at 100% GPU all night 
when you fall asleep without logging out. It also allows your OS to 
start its screen saver or power down the monitor (and other hardware 
devices)

NOTE: The game doesn't really use your AFK status but rather an internal 
"idle" variable. You will go auto-AFK after beeing idle for 5 minutes 
and be logged out after beeing idle for 30 minutes. Since this idle 
variable is not accessible to addons, this addon looks at the AFK status 
and quits after 25 minutes. You will want to enable the "Auto Clear AFK" 
setting if you are running this addon to clear your AFK-flag when you go 
out of idle.

If for some reason the dialog box does not go away when you are no 
longer AFK, type /afk and then move again. Please report if you find a 
way to make this happen. :)

]]

AFKQTEXT = "You are AFK.  AFKQ will quit back to your operating system in %d %s.  Move your character to abort."

local afkq = {}
afkq.timeout = (25*60) - 15

StaticPopupDialogs["AFKQ_TIME_LEFT"] = {
	text = AFKQTEXT,
	button1 = "Quit Now",
	OnAccept = function(self)
		ForceQuit()
	end,
	OnHide = function(self)
		if (self.timeleft < 1) then
			ForceQuit()
		end
	end,
	OnUpdate = function(self, elapsed)
		local text = _G[self:GetName().."Text"];
		local timeleft = self.timeleft
		if ( timeleft < 60 ) then
			text:SetFormattedText(AFKQTEXT, timeleft, SECONDS);
		else
			text:SetFormattedText(AFKQTEXT, ceil(timeleft / 60), MINUTES);
		end

		StaticPopup_Resize(self, "AFKQ_TIME_LEFT");
	end,
	timeout = afkq.timeout,
	whileDead = 1,
	interruptCinematic = 1,
	notClosableByLogout = 1
};


--
--
function afkq.OnEvent(self, event, arg1)
	if ( event == "CHAT_MSG_SYSTEM" ) then
		if ( arg1 and arg1 == arg1:match(MARKED_AFK_MESSAGE:gsub(" %%s$", " .*"))) then
			StaticPopup_Show("AFKQ_TIME_LEFT", afkq.timeout, SECONDS)
		elseif ( arg1 and arg1 == CLEARED_AFK ) then
			StaticPopup_Hide("AFKQ_TIME_LEFT")
		end
	end
end


-- setup
--
afkq.frame = CreateFrame("Frame", "afkQuit", UIParent)
afkq.frame:RegisterEvent("CHAT_MSG_SYSTEM")
afkq.frame:SetScript("OnEvent", afkq.OnEvent)
afkq.frame:Show()
